@@ -28,6 +28,7 @@ class Element(ModuleInterface):
         """
         GET_ELEMENT = "GET_ELEMENT"
         GET_ELEMENT_NAME = "GET_ELEMENT_NAME"
+        GET_ELEMENT_RECTANGLE_BOUNDING = "GET_ELEMENT_RECTANGLE_BOUNDING"
         FOCUS_ELEMENT = "FOCUS_ELEMENT"
         IS_ELEMENT_ENABLED = "IS_ELEMENT_ENABLED"
         NAME_SHOULD_BE = "NAME_SHOULD_BE"
@@ -64,7 +65,7 @@ class Element(ModuleInterface):
             name (String): Name from element
             xpath (String): Searched element as xpath
             retries (Number): Retry counter to repeat calls as number
-            use_exception (Bool) : Indicator to ignore exception handling by flaui
+            use_exception (Bool) : Indicator to ignore exception handling by Flaui
             msg (String): Optional error message
         """
         return Element.Container(name=Converter.cast_to_string(name),
@@ -90,6 +91,10 @@ class Element(ModuleInterface):
             * Values ["xpath"]
             * Returns (String): UI entity name from XPATH
 
+          *  Action.GET_ELEMENT_RECTANGLE_BOUNDING
+            * Values ["xpath"]
+            * Returns (String): UI entity name from XPATH
+
           *  Action.IS_ELEMENT_ENABLED
             * Values ["xpath"]
             * Returns : True if element is enabled otherwise False
@@ -142,6 +147,8 @@ class Element(ModuleInterface):
             self.Action.FOCUS_ELEMENT: lambda: self._get_element(values["xpath"]).Focus(),
             self.Action.GET_ELEMENT: lambda: self._get_element(values["xpath"]),
             self.Action.GET_ELEMENT_NAME: lambda: self._get_name_from_element(values["xpath"]),
+            self.Action.GET_ELEMENT_RECTANGLE_BOUNDING: lambda: self._get_rectangle_bounding_from_element(
+                values["xpath"]),
             self.Action.IS_ELEMENT_ENABLED: lambda: self._get_element(values["xpath"]).IsEnabled,
             self.Action.NAME_SHOULD_BE: lambda: self._name_should_be(values["xpath"], values["name"]),
             self.Action.NAME_SHOULD_CONTAINS: lambda: self._name_should_contain(values["xpath"], values["name"]),
@@ -168,10 +175,26 @@ class Element(ModuleInterface):
             xpath (string): XPath identifier from element.
 
         Raises:
-            COMException: If node don't exists.
+            COMException: If node don't exist.
         """
         return self._get_element(xpath).Name
 
+    def _get_rectangle_bounding_from_element(self, xpath: str):
+        """
+        Get rectangle bounding from element if exists.
+
+        Args:
+            xpath (string): XPath identifier from element.
+
+        Raises:
+            COMException: If node don't exist.
+        """
+        rect = self._get_element(xpath).BoundingRectangle
+        return [Converter.cast_to_int(rect.X),
+                Converter.cast_to_int(rect.Y),
+                Converter.cast_to_int(rect.Width),
+                Converter.cast_to_int(rect.Height)]
+
     def _name_should_be(self, xpath: str, name: str):
         """
         Verifies if name is equal.
@@ -186,7 +209,7 @@ class Element(ModuleInterface):
         """
         element_name = self._get_name_from_element(xpath)
 
-        if not element_name == name:
+        if element_name != name:
             raise FlaUiError(FlaUiError.ElementNameNotEquals.format(element_name, name))
 
     def _name_should_contain(self, xpath: str, name: str):
@@ -287,7 +310,7 @@ class Element(ModuleInterface):
             xpath (string): XPath identifier from element.
 
         Raises:
-            FlaUiError: If node could found by xpath.
+            FlaUiError: If node could not be found from xpath.
             FlaUiError: If node by xpath is not visible.
         """
         hidden = self._get_element(xpath).IsOffscreen
@@ -302,7 +325,7 @@ class Element(ModuleInterface):
             xpath (string): XPath identifier from element.
 
         Raises:
-            FlaUiError: If node could found by xpath.
+            FlaUiError: If node could not be found from xpath.
             FlaUiError: If node by xpath is visible.
         """
         hidden = self._get_element(xpath).IsOffscreen
